@@ -1,6 +1,6 @@
 from socialnetwork.base.backends import BaseSocialBackend
-from socialnetwork.facebook.models import FacebookProfile
+from socialnetwork.facebook.models import FacebookOAuthProfile
 
 
 class FacebookBackend(BaseSocialBackend):
-    model = FacebookProfile
+    model = FacebookOAuthProfile
