@@ -18,6 +18,6 @@ urlpatterns = patterns('',
     ),
     url(
         r'^disconnect/$',
-        views.FacebookProfileDisconnect.as_view(), name='disconnect'
+        views.FacebookOAuthProfileDisconnect.as_view(), name='disconnect'
     ),
 )
